{% extends "admin/base.html" %}

{% block title %}{{ title }} | {{ site_title|default:_('Django site admin') }}{% endblock %}

{% block blockbots %}
<meta name="robots" content="NONE,NOARCHIVE" />
<style>
.login #header h1 a {
    color: #fff !important;
}

{% if site_type == 'production' %}
#header {
    /* background: #4e579d; */
    background: #e47c60;
}
#branding h1, #branding h1 a:link, #branding h1 a:visited {
    color: #ffecbb;
}
{% else %}
#header {
    background: #417690;
}
#branding h1, #branding h1 a:link, #branding h1 a:visited {
    color: #ffe192;
}
{% endif %}
</style>
{% endblock %}

{% block branding %}
<h1 id="site-name"><a href="{% url 'admin:index' %}">{{ site_header|default:_('Django administration') }}</a></h1>
{% endblock %}

{% block nav-global %}{% endblock %}
